import { defineStore } from 'pinia'
import { Vosk } from '@/renderer/plugins/asr/index'
import type {
  Model
} from '@/renderer/plugins/asr/index'

const voskModelMap: Map<string, Model | null> = new Map();

export type ISettings = {
  asr: 'vosk_asr' | 'xf_asr'
  voskModels: string[]
  voskSelectModel: string
  ttsHost: string
  source: {
    sourceName: string
    sourceId: string
    provider: number
    speaker: string
    description: string
    sex: 1 | 0
  }[]
  selectSource: string
  isFullscreen: 'yes' | 'no'
}

const useSettingsStore = defineStore('settings', {
  persist: true,
  state: () =>
    ({
      asr: 'vosk_asr',
      voskModels: [
        'vosk-model-small-ca-0.4.tar.gz',
        'vosk-model-small-cn-0.3.tar.gz',
        'vosk-model-small-de-0.15.tar.gz',
        'vosk-model-small-en-in-0.4.tar.gz',
        'vosk-model-small-en-us-0.15.tar.gz',
        'vosk-model-small-es-0.3.tar.gz',
        'vosk-model-small-fa-0.4.tar.gz',
        'vosk-model-small-fr-pguyot-0.3.tar.gz',
        'vosk-model-small-it-0.4.tar.gz',
        'vosk-model-small-pt-0.3.tar.gz',
        'vosk-model-small-ru-0.4.tar.gz',
        'vosk-model-small-tr-0.3.tar.gz',
        'vosk-model-small-vn-0.3.tar.gz'
      ],
      voskSelectModel: 'vosk-model-small-cn-0.3.tar.gz',
      ttsHost: 'https://beta.laihua.com',
      source: [],
      selectSource: '',
      isFullscreen: 'no'
    }) as ISettings,
  getters: {},
  actions: {
    async getSource() {
      const resp = await fetch(`${this.$state.ttsHost}/api/live/audioAI/source?platform=31`, {
        method: 'GET',
        mode: 'cors'
      })

      const res = await resp.json()

      if (res.code !== 200) return
      this.source = res.data
    },
    async downLoadVoskModel() {
      if (voskModelMap.has(this.$state.voskSelectModel)){
        return voskModelMap.get(this.$state.voskSelectModel) as Model
      }

      const model = await Vosk.createModel(`https://resources.laihua.com/2023-11-29/${this.$state.voskSelectModel}`);
      voskModelMap.set(this.$state.voskSelectModel, model);

      return model;
    }
  }
})

export default useSettingsStore
